==> mmoo_base-1.0.0-dev.1.tar.gz: lib/ui/button_text_widget.dart <==
import 'package:flutter/material.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';

///buttonText
class ButtonTextWidget extends StatefulWidget {
  final Widget child;
  final GestureTapCallback? onPressed;
  final EdgeInsetsGeometry? margin;
  final EdgeInsetsGeometry? padding;
  final Color colorLeft;
  final Color color;
  final Color bgColor;
  final BorderSide? side;

  ButtonTextWidget(
      this.child, this.onPressed, this.colorLeft, this.color, this.bgColor,
      {Key? key, this.margin, this.padding, this.side})
      : super(key: key);

  @override
  ButtonTextWidgetState createState() => ButtonTextWidgetState();
}

class ButtonTextWidgetState extends State<ButtonTextWidget> {
  @override
  Widget build(BuildContext context) {
    return Container(
      padding: widget.margin,
      child: InkWell(
          overlayColor: MaterialStateProperty.all(widget.bgColor),
          child: Container(
              decoration: ShapeDecoration(
                  gradient: LinearGradient(
                    colors: widget.onPressed == null
                        ? [
                            widget.colorLeft.withAlpha(100),
                            widget.color.withAlpha(100)
                          ]
                        : [widget.colorLeft, widget.color],
                  ),
                  shape: StadiumBorder(side: widget.side ?? BorderSide.none)),
              width: ScreenUtil().screenWidth,
              padding: widget.padding ??
                  EdgeInsets.only(
                      top: ScreenUtil().setWidth(15),
                      bottom: ScreenUtil().setWidth(15)),
              alignment: Alignment.center,
              child: widget.child),
          onTap: widget.onPressed),
    );
  }
}

==> mmoo_base-1.1.0-dev.7.tar.gz: lib/ui/button_text_widget.dart <==
import 'package:flutter/material.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';

///buttonText
class ButtonTextWidget extends StatefulWidget {
  final Widget child;
  final VoidCallback? onPressed;
  final EdgeInsetsGeometry? margin;
  final EdgeInsetsGeometry? padding;
  final Color colorLeft;
  final Color color;
  final Color bgColor;
  final BorderSide? side;
  final bool width;
  final List<BoxShadow>? shadows;

  ButtonTextWidget(
      this.child, this.onPressed, this.colorLeft, this.color, this.bgColor,
      {Key? key,
      this.margin,
      this.padding,
      this.side,
      this.width = true,
      this.shadows})
      : super(key: key);

  @override
  ButtonTextWidgetState createState() => ButtonTextWidgetState();
}

class ButtonTextWidgetState extends State<ButtonTextWidget> {
  @override
  Widget build(BuildContext context) {
    return Container(
      padding: widget.margin,
      child: InkWell(
          overlayColor: MaterialStateProperty.all(widget.bgColor),
          child: Container(
              decoration: ShapeDecoration(
                gradient: LinearGradient(
                  colors: widget.onPressed == null
                      ? [
                          widget.colorLeft.withAlpha(100),
                          widget.color.withAlpha(100)
                        ]
                      : [widget.colorLeft, widget.color],
                ),
                shape: StadiumBorder(side: widget.side ?? BorderSide.none),
                shadows: widget.shadows,
              ),
              width: widget.width ? ScreenUtil().screenWidth : null,
              padding: widget.padding ??
                  EdgeInsets.only(
                      top: ScreenUtil().setWidth(15),
                      bottom: ScreenUtil().setWidth(15)),
              alignment: Alignment.center,
              child: widget.child),
          onTap: widget.onPressed),
    );
  }
}
